@@ -70,7 +70,7 @@ class InteractiveSearchBox():
         function handling keypresses from the treeview
         for the typeahead find capabilities
         """
-        if not event.string:
+        if not Gdk.keyval_to_unicode(event.keyval):
             return False
         if self._key_cancels_search(event.keyval):
             return False
@@ -440,6 +440,8 @@ class InteractiveSearchBox():
         search_column = self._treeview.get_search_column()
         is_tree = not (model.get_flags() & Gtk.TreeModelFlags.LIST_ONLY)
         while True:
+            if not cur_iter:    # can happen on empty list
+                return False
             if (self.search_equal_func(model, search_column,
                                        text, cur_iter)):
                 count += 1
