@@ -363,7 +363,7 @@ class GrampsXmlWriter(UpdateCallback):
             for key in group_map:
                 value = self.db.get_name_group_mapping(key)
                 self.g.write('    <map type="group_as" key="%s" value="%s"/>\n'
-                             % (key, value) )
+                             % (self.fix(key), value))
             self.g.write("  </namemaps>\n")
 
     def write_bookmarks(self):
